# Copula Distributions

This directory contains all implemented CopulAX copula distributions.

## Implemented Copula Distributions

Currently the following copula distributions are implemented in copulAX:
| Object / Module | Distribution |
| --- | --- |
| gaussian_copula | [Gaussian/Normal Copula](<https://en.wikipedia.org/wiki/Copula*(statistics)>)|
| student_t_copula | [Student's T Copula](https://en.wikipedia.org/wiki/Multivariate_t-distribution)|
| gh_copula | [Generalized Hyperbolic Copula](https://en.wikipedia.org/wiki/Generalised_hyperbolic_distribution)|
| skewed_t_copula |Skewed/Asymmetric Student's T Copula|
